@@ -7,9 +7,11 @@ import sys
 
 from flask import Flask, Blueprint
 from flask_restful import Api
-from typing import Dict, Any    # noqa: F401
+from flask_cors import CORS
+from typing import Dict, Any  # noqa: F401
 from flasgger import Swagger
 
+from search_service.api.dashboard import SearchDashboardAPI
 from search_service.api.table import SearchTableAPI, SearchTableFieldAPI, SearchTableFilterAPI
 from search_service.api.user import SearchUserAPI
 from search_service.api.document import DocumentUserAPI, DocumentTableAPI, DocumentTablesAPI, DocumentUsersAPI
@@ -21,6 +23,9 @@ FLASK_APP_CLASS_NAME = os.getenv('FLASK_APP_CLASS_NAME')
 FLASK_APP_KWARGS_DICT_STR = os.getenv('FLASK_APP_KWARGS_DICT')
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 
+# Environment Variable to enable cors
+CORS_ENABLED = os.environ.get('CORS_ENABLED', False)
+
 
 def create_app(*, config_module_class: str) -> Flask:
     """
@@ -56,6 +61,8 @@ def create_app(*, config_module_class: str) -> Flask:
     else:
         app = Flask(__name__)
 
+    if CORS_ENABLED:
+        CORS(app)
     config_module_class = \
         os.getenv('SEARCH_SVC_CONFIG_MODULE_CLASS') or config_module_class
     app.config.from_object(config_module_class)
@@ -83,6 +90,9 @@ def create_app(*, config_module_class: str) -> Flask:
     # User Search API
     api.add_resource(SearchUserAPI, '/search_user')
 
+    # Dashboard Search API
+    api.add_resource(SearchDashboardAPI, '/search_dashboard')
+
     # DocumentAPI
     api.add_resource(DocumentTablesAPI, '/document_table')
     api.add_resource(DocumentTableAPI, '/document_table/<document_id>')
