@@ -7,6 +7,10 @@ from flasgger import swag_from
 
 from search_service.proxy import get_proxy_client
 
+tag_fields = {
+    "tag_name": fields.String
+}
+
 table_fields = {
     "name": fields.String,
     "key": fields.String,
@@ -17,7 +21,9 @@ table_fields = {
     "schema": fields.String,
     "column_names": fields.List(fields.String),
     # tags can be empty list
-    "tags": fields.List(fields.String),
+    "tags": fields.List(fields.Nested(tag_fields)),
+    # badges can be an empty list
+    "badges": fields.List(fields.Nested(tag_fields)),
     # last etl timestamp as epoch
     "last_updated_timestamp": fields.Integer,
     "display_name": fields.String
@@ -52,6 +58,7 @@ class SearchTableAPI(Resource):
     def get(self) -> Iterable[Any]:
         """
         Fetch search results based on query_term.
+
         :return: list of table results. List can be empty if query
         doesn't match any tables
         """
@@ -154,10 +161,15 @@ class SearchTableFilterAPI(Resource):
             msg = 'The search request payload is not available in the request'
             return {'message': msg}, HTTPStatus.BAD_REQUEST
 
+        query_term = args.get('query_term')  # type: str
+        if ':' in query_term:
+            msg = 'The query term contains an invalid character'
+            return {'message': msg}, HTTPStatus.BAD_REQUEST
+
         try:
             results = self.proxy.fetch_table_search_results_with_filter(
                 search_request=search_request,
-                query_term=args.get('query_term'),
+                query_term=query_term,
                 page_index=page_index,
                 index=args['index']
             )
